@@ -11,6 +11,7 @@ import deskbar.interfaces.Match
 from deskbar.defs import VERSION
 from deskbar.core.Watcher import FileWatcher
 from deskbar.handlers.actions.OpenWithNautilusAction import OpenWithNautilusAction
+from deskbar.handlers.actions.OpenFileAction import OpenFileAction
 from deskbar.handlers.actions.ShowUrlAction import ShowUrlAction
 from deskbar.handlers.actions.CopyToClipboardAction import CopyToClipboardAction
 from deskbar.handlers.actions.ActionsFactory import get_actions_for_uri
@@ -25,10 +26,10 @@ class FileMatch(deskbar.interfaces.Match):
     def __init__(self, name=None, absname=None, **args):
         deskbar.interfaces.Match.__init__(self, name=name, icon=absname, category="files", **args)
         self.absname = absname
-        self.add_action( ShowUrlAction(name, absname) )
+        self.add_action( OpenFileAction(name, absname ) )
         self.add_all_actions( get_actions_for_uri(absname) )
     
-    def get_hash(self, text=None):
+    def get_hash(self):
         return self.absname
 
 class FolderMatch(deskbar.interfaces.Match):
@@ -38,7 +39,7 @@ class FolderMatch(deskbar.interfaces.Match):
         self.add_action( ShowUrlAction(name, absname) )
         self.add_all_actions( get_actions_for_uri(absname) )
     
-    def get_hash(self, text=None):
+    def get_hash(self):
         return self.absname
 
 class GtkBookmarkMatch(deskbar.interfaces.Match):
@@ -48,7 +49,7 @@ class GtkBookmarkMatch(deskbar.interfaces.Match):
         self.add_action( OpenWithNautilusAction(name, path) )
         self.add_all_actions( get_actions_for_uri(path) )
     
-    def get_hash(self, text=None):
+    def get_hash(self):
         return self.path
 
 class VolumeMatch (deskbar.interfaces.Match):
@@ -56,9 +57,11 @@ class VolumeMatch (deskbar.interfaces.Match):
         deskbar.interfaces.Match.__init__(self, name=name, category="places", icon=icon, **args)
         self.drive = drive
         self.add_action( OpenWithNautilusAction(name, drive) )
+        # FIXME:
+        # _("Location") should be _("Location of %s") % name
         self.add_action( CopyToClipboardAction(_("Location"), drive) )
 
-    def get_hash(self, text=None):
+    def get_hash(self):
         return self.drive
         
 class FileFolderHandler(deskbar.interfaces.Module):
@@ -108,8 +111,10 @@ class FileFolderHandler(deskbar.interfaces.Module):
             if not drive.is_mounted () : continue
             if not drive.get_display_name().lower().startswith(query): continue
             
-            vol_match = VolumeMatch (drive.get_display_name(), drive.get_activation_uri(), drive.get_icon(), priority=self.get_priority())
-            result.append (vol_match)
+            uri = drive.get_activation_uri()
+            if uri != None:
+                vol_match = VolumeMatch (drive.get_display_name(), uri, drive.get_icon(), priority=self.get_priority())
+                result.append (vol_match)
         
         self._emit_query_ready(query, result )
     
